@@ -22,7 +22,7 @@ class FileLoader {
 			$jsLoadingSequence[] = "client/extjs/ux/ux-all.js";
 			$jsLoadingSequence[] = "client/extjs-mod/extjs-mod.js";
 			$jsLoadingSequence[] = "client/jquery/jquery-1.6.2.min.js";
-			$jsLoadingSequence[] = "client/tinymce/tiny_mce.js";
+			$jsLoadingSequence[] = "client/tinymce/tinymce.min.js";
 			$jsLoadingSequence[] = "client/third-party/ux-thirdparty.js";
 		} else if ($load == LOAD_DEBUG) {
 			$jsLoadingSequence[] = "client/extjs/ext-base-debug.js";
@@ -30,7 +30,7 @@ class FileLoader {
 			$jsLoadingSequence[] = "client/extjs/ux/ux-all-debug.js";
 			$jsLoadingSequence[] = "client/extjs-mod/extjs-mod-debug.js";
 			$jsLoadingSequence[] = "client/jquery/jquery-1.6.2.min.js";
-			$jsLoadingSequence[] = "client/tinymce/tiny_mce_src.js";
+			$jsLoadingSequence[] = "client/tinymce/tinymce.js";
 			$jsLoadingSequence[] = "client/third-party/ux-thirdparty-debug.js";
 		} else {
 			$jsLoadingSequence[] = "client/extjs/ext-base-debug.js";
@@ -43,7 +43,7 @@ class FileLoader {
 				)
 			);
 			$jsLoadingSequence[] = "client/jquery/jquery-1.6.2.min.js";
-			$jsLoadingSequence[] = "client/tinymce/tiny_mce_src.js";
+			$jsLoadingSequence[] = "client/tinymce/tinymce.dev.js";
 			$jsLoadingSequence = array_merge(
 				$jsLoadingSequence,
 				$this->buildJSLoadingSequence(
@@ -70,12 +70,10 @@ class FileLoader {
 			$cssLoadingSequence[] = "client/extjs/resources/css/ext-all.css";
 			$cssLoadingSequence[] = "client/extjs/ux/css/ux-all.css";
 			$cssLoadingSequence[] = "client/third-party/resources/css/ux-thirdparty.css";
-			$cssLoadingSequence[] = "client/tinymce/themes/advanced/skins/default/ui.css";
 		} else if ($load == LOAD_DEBUG) {
 			$cssLoadingSequence[] = "client/extjs/resources/css/ext-all.css";
 			$cssLoadingSequence[] = "client/extjs/ux/css/ux-all.css";
 			$cssLoadingSequence[] = "client/third-party/resources/css/ux-thirdparty.css";
-			$cssLoadingSequence[] = "client/tinymce/themes/advanced/skins/default/ui.css";
 		} else {
 			$cssLoadingSequence[] = "client/extjs/resources/css/ext-all.css";
 			$cssLoadingSequence[] = "client/extjs/ux/css/ux-all.css";
@@ -85,7 +83,6 @@ class FileLoader {
 					$this->getListOfFiles('css', 'client/third-party')
 				)
 			);
-			$cssLoadingSequence[] = "client/tinymce/themes/advanced/skins/default/ui.css";
 		}
 
 		return $cssLoadingSequence;
