@@ -87,21 +87,26 @@
 	}
 
 	if ($logout) {
-		// The user requests to logout. We should destroy the
-		// session, and redirect the user to the logon page.
-		$actionURI = '?load=logon';
+		// REMOTE_USER is set when apache has authenticated the user, means Single Sign-on
+		// environment is in effect. Don't allow user to redirect to the webapp login page
+		// to prevent user to login with other credentials.
+		if (!isset($_SERVER['REMOTE_USER'])){
+			// The user requests to logout. We should destroy the
+			// session, and redirect the user to the logon page.
+			$actionURI = '?load=logon';
 
-		destroySession();
+			destroySession();
 
-		$user = sanitizeGetValue('user', '', USERNAME_REGEX);
-		if ($user) {
-			$actionURI .= '&user=' . rawurlencode($user);
+			$user = sanitizeGetValue('user', '', USERNAME_REGEX);
+			if ($user) {
+				$actionURI .= '&user=' . rawurlencode($user);
+			}
+
+			// Redirect the user, this will reload the page
+			// and request the logon page.
+			header('Location: index.php' . $actionURI, true, 303);
+			exit;
 		}
-
-		// Redirect the user, this will reload the page
-		// and request the logon page.
-		header('Location: index.php' . $actionURI, true, 303);
-		exit;
 	} else if ($logon) {
 		// The user requested to logon. Check if credentials were provided
 		// or if the a remote user login is possible.
@@ -157,6 +162,11 @@
 	} else if ($load !== 'logon' && isset($_SESSION["username"]) && isset($_SESSION["password"])) {
 		$sslcert_file = defined('SSLCERT_FILE') ? SSLCERT_FILE : null;
 		$sslcert_pass = defined('SSLCERT_PASS') ? SSLCERT_PASS : null;
+
+		if(!isset($_SESSION['lang']))
+		    $_SESSION['lang'] = LANG;
+	        setlocale(LC_MESSAGES, LANG);
+
 		$hresult = $GLOBALS["mapisession"]->logon($_SESSION["username"], $_SESSION["password"], DEFAULT_SERVER, $sslcert_file, $sslcert_pass);
 	}
 
@@ -352,9 +362,16 @@
 			}
 		}
 
-		// NOTE: We have saved the $hresult in the $GLOBALS
-		// object, the login.php will obtain the code from there.
-		include("client/login.php");
+		// REMOTE_USER is set when apache has authenticated the user, means Single Sign-on
+		// environment is in effect. Don't redirect to the webapp login form.
+		if (!isset($_SERVER['REMOTE_USER'])){
+			// NOTE: We have saved the $hresult in the $GLOBALS
+			// object, the login.php will obtain the code from there.
+			include("client/login.php");
+		} else {
+			header('Location: index.php', true, 303);
+			exit;
+		}
 	} else if ($hresult === MAPI_E_NETWORK_ERROR) {
 		// The user is not logged in because the zarafa-server could not be reached.
 		// Return a HTTP 503 error so the client can act upon this event correctly.
