@@ -6,7 +6,4 @@ define("LOAD_RELEASE", 1);
 define("LOAD_DEBUG", 2);
 // Load the original source files (for developers)
 define("LOAD_SOURCE", 3);
-
-// Disable PHP5>PHP4 compatibility, this could segfault apache with xml_parser_free
-ini_set('zend.ze1_compatibility_mode', false);         
 ?>
