@@ -50,6 +50,7 @@ class Pluginspreed extends Plugin {
 					'plugins' => Array(
 						'spreed' => Array(
 							'enable'            => PLUGIN_SPREED_USER_DEFAULT_ENABLE,
+							'max_participants'  => PLUGIN_SPREED_MAX_PARTICIPANTS,
 							'default_timezone'  => date_default_timezone_get(),
 						)
 
@@ -59,3 +60,4 @@ class Pluginspreed extends Plugin {
 		));
 	}
 }
+?>
