@@ -7,7 +7,7 @@ require_once('PEAR/JSON.php');
  */
 class ConfigCheck 
 {
-	var $result;
+	public $result;
 
 	function ConfigCheck($haltOnError = true)
 	{
