@@ -393,10 +393,14 @@ class AttachmentState {
 
 		// remove base directory also
 		if(is_dir($this->sessiondir)) {
+			/**
+			 * FIXME: We should remove the folder when it is not needed,
+			 * Because of WA-6523 this is creating an issue, so need to fix this properly
+			 */
 			// Directory should be empty to remove it, So first remove all files in the directory
-			if(function_exists("glob")) {
+			/*if(function_exists("glob")) {
 				array_map('unlink', glob($this->sessiondir . "/*"));
-			}
+			}*/
 			rmdir($this->sessiondir);
 		}
 	}
