@@ -231,7 +231,7 @@
 				if (($entryID === REQUEST_ENTRYID && $folderNotifier['entryid'] === REQUEST_ENTRYID) ||
 				    ($entryidCmp->compareEntryIds($folderNotifier['entryid'], $entryID))) {
 					foreach ($folderNotifier as $key => $notifier) {
-						if ($notifier['events'] & $event) {
+						if (isset($notifier['events']) && ($notifier['events'] & $event)) {
 							if (!isset($updatedNotifiers[$key])) {
 								if (isset($this->notifiers[$key]) && is_object($this->notifiers[$key])) {
 									$this->notifiers[$key]->update($event, $entryID, $data);
