@@ -105,6 +105,19 @@
 			} catch (Exception $e) {
 				// handle exceptions that are not handled by modules
 				dump($e);
+
+				$data = array(
+					"error" => array(
+						"type" => ERROR_GENERAL,
+						"info" => array(
+							"file" => basename($e->getFile()) . ':' . $e->getLine(),
+							"display_message" => _('An unexpected error has occurred'),
+							"original_message" => $e->getMessage()
+						)
+					)
+				);
+
+				return JSON::Encode(array("zarafa" => $data));
 			}
 		}
 	}
