@@ -346,8 +346,13 @@
 					$trans_str = unpack('a'.$length.'str', fread($fp, $length));
 					$translation_data[$i]['msgstr'] = $trans_str['str'];	// unpack converts to array :S
 
-					// Find plural forms in the translated string
-					if(strpos($translation_data[$i]['msgstr'], "\0") !== false){
+					// If there are plural forms in the source string,
+					// then the translated string must contain plural
+					// forms as well.  We cannot depend on a \0 being
+					// present at all times, because languages that
+					// have only one plural form won't have this
+					// (e.g. Japanese)
+					if($translation_data[$i]['msgid_plural'] !== false) {
 						$translation_data[$i]['msgstr'] = explode("\0", $translation_data[$i]['msgstr']);
 					}
 				}else{
