@@ -157,7 +157,8 @@
 				$user = mapi_ab_openentry($this->getAddressbook(), $store_props[PR_USER_ENTRYID]);
 
 				// receive userdata
-				$user_props = mapi_getprops($user, array(PR_DISPLAY_NAME, PR_SMTP_ADDRESS, PR_EMAIL_ADDRESS, PR_SEARCH_KEY));
+				// TODO: 0x8C9E0102 represents an LDAP jpegPhoto and should get a named property PR_EMS_AB_THUMBNAIL_PHOTO
+				$user_props = mapi_getprops($user, array(PR_DISPLAY_NAME, PR_SMTP_ADDRESS, PR_EMAIL_ADDRESS, PR_SEARCH_KEY, 0x8C9E0102));
 
 				if (is_array($user_props) && isset($user_props[PR_DISPLAY_NAME]) && isset($user_props[PR_SMTP_ADDRESS])){
 					$this->session_info["userentryid"] = $store_props[PR_USER_ENTRYID];
@@ -165,6 +166,8 @@
 					$this->session_info["smtpaddress"] = $user_props[PR_SMTP_ADDRESS];
 					$this->session_info["emailaddress"] = $user_props[PR_EMAIL_ADDRESS];
 					$this->session_info["searchkey"] = $user_props[PR_SEARCH_KEY];
+					$this->session_info["userimage"] = isset($user_props[-1935802110]) ? base64_encode($user_props[-1935802110]) : "";
+					$this->session_info["userimage"] = strlen($this->session_info["userimage"]) > 0 ? "data:image/png;base64," . $this->session_info["userimage"] : "" ;
 				}
 
 				$this->userDataRetrieved = true;
@@ -299,6 +302,17 @@
 			return array_key_exists("emailaddress",$this->session_info)?$this->session_info["emailaddress"]:false;
 		}
 
+		/**
+		 * Get current user's image from the LDAP server
+		 * @return string A base64 encoded string (data url)
+		 */
+		function getUserImage()
+		{
+			$result = $this->retrieveUserData();
+
+			return array_key_exists("userimage",$this->session_info)? $this->session_info["userimage"]:false;
+		}
+
 		/**
 		 * Get current user's search key
 		 * @return string Current user's searchkey
