@@ -163,14 +163,17 @@ class PluginManager
 			// Read all plugins from the plugins folders.
 			$this->plugindata = $this->readPluginFolder($disabledPlugins);
 
-			// Not we update plugindata and pluginorder based on the configured dependencies.
-			// Note that each change to plugindata requires the requirements and dependencies
-			// to be recalculated.
-			while (!$this->pluginorder || !$this->validatePluginRequirements()) {
-				// Generate the order in which the plugins should be loaded,
-				// this uses the $this->plugindata as base.
-				$this->pluginorder = $this->buildPluginDependencyOrder();
-			};
+			// Check if any plugin directories found or not
+			if (!empty($this->plugindata) ) {
+				// Not we update plugindata and pluginorder based on the configured dependencies.
+				// Note that each change to plugindata requires the requirements and dependencies
+				// to be recalculated.
+				while (!$this->pluginorder || !$this->validatePluginRequirements()) {
+					// Generate the order in which the plugins should be loaded,
+					// this uses the $this->plugindata as base.
+					$this->pluginorder = $this->buildPluginDependencyOrder();
+				};
+			}
 		}
 
 		// Write the plugindata back to the state
