@@ -706,6 +706,7 @@
 				$properties["ems_ab_is_member_of_dl"] = PR_EMS_AB_IS_MEMBER_OF_DL;
 				$properties["ems_ab_proxy_addresses"] = PR_EMS_AB_PROXY_ADDRESSES;
 				$properties["ems_ab_proxy_addresses_mv"] = PR_EMS_AB_PROXY_ADDRESSES_MV;
+				$properties["ems_ab_thumbnail_photo"] = PR_EMS_AB_THUMBNAIL_PHOTO;
 
 				// Allowing to hook in and add more properties
 				$GLOBALS['PluginManager']->triggerHook("server.core.properties.addressbookitem.mailuser", array(
@@ -845,6 +846,7 @@
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
 				$properties["transport_message_headers"] = PR_TRANSPORT_MESSAGE_HEADERS;
 				$properties["x_original_to"] = "PT_STRING8:PS_INTERNET_HEADERS:x-original-to";
+				$properties["source_message_info"] = "PT_BINARY:PSETID_Common:0x85CE";
 
 				// Corresponding appointment related properties
 				$properties["appointment_startdate"] = "PT_SYSTIME:PSETID_Appointment:0x820d";
@@ -1126,13 +1128,13 @@
 
 			if (!isset($this->mapping[$this->storeMapping]['reminder'])) {
 				$properties = Array();
-		  		$properties["entryid"] = PR_ENTRYID;
-	  			$properties["parent_entryid"] = PR_PARENT_ENTRYID;
+				$properties["entryid"] = PR_ENTRYID;
+				$properties["parent_entryid"] = PR_PARENT_ENTRYID;
 				$properties["store_entryid"] = PR_STORE_ENTRYID;
-	  			$properties["message_class"] = PR_MESSAGE_CLASS;
+				$properties["message_class"] = PR_MESSAGE_CLASS;
 				$properties["message_flags"] = PR_MESSAGE_FLAGS;
-	  			$properties["icon_index"] = PR_ICON_INDEX;
-	  			$properties["subject"] = PR_SUBJECT;
+				$properties["icon_index"] = PR_ICON_INDEX;
+				$properties["subject"] = PR_SUBJECT;
 				$properties["object_type"] = PR_OBJECT_TYPE;
 
 				$properties["reminder"] = "PT_BOOLEAN:PSETID_Common:0x8503";				// PidLidReminderSet
