@@ -283,7 +283,10 @@
 								$item['fileas'] = $user_data[$this->properties['account']];
 							case DT_PRIVATE_DISTLIST:
 								$item['email_address'] = $user_data[$this->properties['account']];
-								$item['smtp_address'] = $user_data[$this->properties['smtp_address']];
+								// FIXME: shouldn't be needed, but atm this gives us an undefined offset error which makes the unittests fail.
+								if($item['email_address'] !== 'Everyone') {
+									$item['smtp_address'] = $user_data[$this->properties['smtp_address']];
+								}
 								$item['address_type'] = 'ZARAFA';
 								break;
 
