@@ -119,15 +119,23 @@
 
 					if($send) {
 						// Allowing to hook in just before the data sent away to be sent to the client
+						$succes = true;
 						$GLOBALS['PluginManager']->triggerHook('server.module.createmailitemmodule.beforesend', array(
 							'moduleObject' => $this,
 							'store' => $store,
 							'entryid' => $entryid,
 							'action' =>$action,
+							'success' => &$succes,
+							'properties' => $this->properties,
+							'messageProps' => $messageProps,
+							'parententryid' => $parententryid,
 							));
+						// Break out, hook should use sendFeedback to return a response to the client.
+						if(!$succes) {
+							return;
+						}
 
-						$prop = Conversion::mapXML2MAPI($this->properties, $action['props']);
-
+						$this->setReplyForwardInfo($action);
 						$result = $GLOBALS['operations']->submitMessage($store, $entryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
 
 						// If draft is sent from the drafts folder, delete notification
@@ -194,41 +202,6 @@
 
 						$this->addActionData('update', array('item' => $data));
 					}
-
-					// Reply/Reply All/Forward Actions (ICON_INDEX & LAST_VERB_EXECUTED)
-					// we don't care if we are replying/forwarding from embedded message, as we don't want to save these
-					// properties in embedded message
-					if($copyFromMessage && $copyFromStore && empty($action['message_action']['source_attach_num'])) {
-						$props = array();
-						$props[$this->properties['entryid']] = hex2bin($action['message_action']['source_entryid']);
-
-						switch($action['message_action']['action_type'])
-						{
-							case 'reply':
-								$props[$this->properties['icon_index']] = 261;
-								$props[$this->properties['last_verb_executed']] = 102;
-								break;
-							case 'replyall':
-								$props[$this->properties['icon_index']] = 261;
-								$props[$this->properties['last_verb_executed']] = 103;
-								break;
-							case 'forward':
-								$props[$this->properties['icon_index']] = 262;
-								$props[$this->properties['last_verb_executed']] = 104;
-								break;
-						}
-
-						$props[$this->properties['last_verb_execution_time']] = time();
-
-						$messageActionProps = array();
-						$messageActionResult = $GLOBALS['operations']->saveMessage($copyFromStore, $props[PR_ENTRYID], $parententryid, $props, $messageActionProps);
-
-						if($messageActionResult) {
-							if(isset($messageActionProps[PR_PARENT_ENTRYID])) {
-								$GLOBALS['bus']->notify(bin2hex($messageActionProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageActionProps);
-							}
-						}
-					}
 				}
 
 				// Feedback for successful save (without send)
@@ -244,5 +217,96 @@
 				$this->sendFeedback($result ? true : false, array(), true);
 			}
 		}
+
+		/**
+		 * Function which is used to get the source message information, which contains the information of 
+		 * reply/forward and entry id of original mail, where we have to set the reply/forward arrow when 
+		 * draft(saved mail) is send.
+		 * @param array $action the action data, sent by the client
+		 * @return number return source_message_info value from record else return false.
+		 */
+		function getSourceMsgInfo($action)
+		{
+			if(isset($action["props"]["source_message_info"]) && !empty($action["props"]["source_message_info"])) {
+				return $action["props"]["source_message_info"];
+			} else if(isset($action["entryid"]) && !empty($action["entryid"])) {
+				$entryid = hex2bin($action['entryid']);
+				$storeEntryid = hex2bin($action['store_entryid']);
+				$store = $GLOBALS['mapisession']->openMessageStore($storeEntryid);
+				$message = $GLOBALS['operations']->openMessage($store, $entryid);
+				$messageProps = mapi_getprops($message);
+				$props = Conversion::mapMAPI2XML($this->properties, $messageProps);
+				$sourceMsgInfo = !empty($props['props']['source_message_info']) ? $props['props']['source_message_info'] : false;
+				return $sourceMsgInfo;
+			}
+
+			return false;
+		}
+
+		/**
+		 * Function is used to set the reply/forward arrow on original mail.
+		 * @param object $store MAPI Message Store Object
+		 * @param array $action the action data, sent by the client
+		 */
+		function setReplyForwardInfo($action)
+		{
+			$message = false;
+			$sourceMsgInfo = $this->getSourceMsgInfo($action);
+			if($sourceMsgInfo) {
+				/**
+				 * $sourceMsgInfo contains the hex value, where first 24byte contains action type 
+				 * and next 48byte contains entryid of original mail. so we have to extract the action type 
+				 * from this hex value.
+				 * 
+				 * Example : 01000E000C00000005010000660000000200000030000000 + record entryid
+				 * Here 66 represents the REPLY action type. same way 67 and 68 is represent
+				 * REPLY ALL and FORWARD respectively.
+				 */
+				$mailActionType = substr($sourceMsgInfo, 24, 2);
+				// get the entry id of origanal mail's.
+				$originalEntryid = substr($sourceMsgInfo, 48);
+				$entryid = hex2bin($originalEntryid);
+				$storeEntryid = hex2bin($action['store_entryid']);
+				$store = $GLOBALS['mapisession']->openMessageStore($storeEntryid);
+				try {
+					// if original mail of reply/forward mail is deleted from inbox then,
+					// it will throw an exception so to handle it we need to write this block in try catch.
+					$message = $GLOBALS['operations']->openMessage($store, $entryid);
+				}catch(MAPIException $e) {
+					$e->setHandled();
+				}
+
+				if($message) {
+					$messageProps = mapi_getprops($message);
+					$props = Conversion::mapMAPI2XML($this->properties, $messageProps);
+					switch($mailActionType) {
+						// Reply
+						case '66':
+							$props['icon_index'] = 261;
+							$props['last_verb_executed'] = bin2hex("66");
+							break;
+						// Reply All
+						case '67':
+							$props['icon_index'] = 261;
+							$props['last_verb_executed'] = bin2hex("67");
+							break;
+						// Forward
+						case '68':
+							$props['icon_index'] = 262;
+							$props['last_verb_executed'] = bin2hex("68");
+							break;
+					}
+					$props['last_verb_execution_time'] = time();
+					$mapiProps = Conversion::mapXML2MAPI($this->properties, $props);
+					$messageActionProps = array();
+					$messageActionResult = $GLOBALS['operations']->saveMessage($store, $mapiProps[PR_ENTRYID], $mapiProps[PR_PARENT_ENTRYID], $mapiProps, $messageActionProps);
+					if($messageActionResult) {
+						if(isset($messageActionProps[PR_PARENT_ENTRYID])) {
+							$GLOBALS['bus']->notify(bin2hex($messageActionProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageActionProps);
+						}
+					}
+				}
+			}
+		}
 	}
 ?>
