@@ -213,15 +213,15 @@
 								$store = $GLOBALS["mapisession"]->addUserStore($username);
 								if ($store) {
 									$options = array( $username => array( $action["folder_type"] => $action ));
-									$data = $GLOBALS["operations"]->getHierarchyList($this->list_properties, HIERARCHY_GET_ONE, $store, $options);
+									$data = $GLOBALS["operations"]->getHierarchyList($this->list_properties, HIERARCHY_GET_ONE, $store, $options, $username);
 
 									// Check if we have obtained a store, and if that store has read access
 									if (!empty($data["item"][0]["folders"]["item"]) &&
-									    // We expect multiple folders, as it should always return the IPM_SUBTREE 
-									    // besides the actual opened folder
-									    count($data["item"][0]["folders"]["item"]) > 1 && 
-									    // Check the second folder as the first one is the IPM_SUBTREE
-									    $data["item"][0]["folders"]["item"][1]["props"]["access"] !== 0) {
+										// We expect multiple folders, as it should always return the IPM_SUBTREE 
+										// besides the actual opened folder
+										count($data["item"][0]["folders"]["item"]) > 1 && 
+										// Check the second folder as the first one is the IPM_SUBTREE
+										$data["item"][0]["folders"]["item"][1]["props"]["access"] !== 0) {
 										$this->addActionData("list", $data);
 									} else {
 										// Throw an exception that we couldn't open the shared store,
