@@ -71,6 +71,17 @@
 												$message = $GLOBALS["operations"]->openMessage($store, $entryid);
 												$basedate = (isset($action['basedate']) ? $action['basedate'] : false);
 												$delete = false;
+
+												if($basedate) {
+													$recurrence = new Recurrence($store, $message);
+													$exceptionatt = $recurrence->getExceptionAttachment($basedate);
+													if($exceptionatt) {
+														//get properties of existing exception.
+														$exceptionattProps = mapi_getprops($exceptionatt, array(PR_ATTACH_NUM));
+														$attach_num = $exceptionattProps[PR_ATTACH_NUM];
+													}
+												}
+
 												/**
 												 * Get message class from original message. This can be changed to
 												 * IPM.Appointment if the item is a Meeting Request in the maillist.
@@ -124,6 +135,13 @@
 												 */
 												$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID));
 
+												// if opened appointment is exception then it will add 
+												// the attach_num and basedate in messageProps.
+												if(isset($attach_num)) {
+													$messageProps[PR_ATTACH_NUM] = array($attach_num);
+													$messageProps[$properties["basedate"]] = $basedate;
+												}
+
 												if($delete) {
 													// send TABLE_DELETE event because the message has moved
 													$this->sendFeedback(true);
@@ -408,7 +426,7 @@
 			if($attachNum) {
 				// get message props of sub message
 				$parentMessage = $message;
-				$message = $GLOBALS['operations']->openMessage($store, $entryid, $attachNum);
+				$message = $GLOBALS['operations']->openMessage($store, $entryid, $attachNum, true);
 
 				if(empty($message)) {
 					return;
