@@ -154,8 +154,6 @@
 				// Sort
 				$this->parseSortOrder($action, null, true);
 
-				// @TODO add implementation of https://jira.zarafa.com/browse/ZCP-9325
-
 				// Get the table and merge the arrays
 				$data = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction);
 
@@ -283,6 +281,9 @@
 			// Wait until we have some data, no point in returning before we have data. Stop waiting after 10 seconds
 			$start = time();
 			$table = mapi_folder_getcontentstable($searchFolder, MAPI_DEFERRED_ERRORS);
+
+			// Sleep for 0.2 seconds initially, since it usually takes ~  0.2 seconds to fill the search folder. 
+			sleep(0.2);
 			
 			while(time() - $start < 10) {
 				$count = mapi_table_getrowcount($table);
@@ -295,7 +296,7 @@
 				if(($result["searchstate"] & SEARCH_REBUILD) == 0)
 					break; // Search is done
 				
-				sleep(1);
+				sleep(0.1);
 			}
 
 			// Get the table and merge the arrays
