@@ -74,6 +74,16 @@
 
 					$newfiles[] = $attachid;
 
+					// Allow hooking in to handle uploads in plugins
+					$GLOBALS['PluginManager']->triggerHook('server.upload_attachment.upload', array(
+						'moduleObject' =>& $this,
+						'tmpname'  => $attachment_state->getAttachmentPath($attachid),
+						'name' => $filename,
+						'size' => $FILE['size'],
+						'sourcetype' => $sourcetype,
+						'returnfiles' =>& $returnfiles
+					));
+
 					if($sourcetype === 'contactphoto') {
 						$returnfiles[] = Array(
 							'props' => Array(
